@@ -8,7 +8,11 @@
 # ------------------------------------------------------------------------------
 
 import argparse
-import importlib.metadata as metadata
+
+try:
+    import importlib.metadata as metadata
+except ImportError:
+    import importlib_metadata as metadata
 
 import numpy as np
 
@@ -121,6 +125,7 @@ def cli():
         choices=["heun", "imp_poly", "ralston"],
         default="heun",
     )
+    
     optional.add_argument(
         "--outf",
         help="output video filename Default: output.mp4",
